==> apache-cxf-3.6.4-src.tar.gz: apache-cxf-3.6.4-src/systests/uncategorized/src/test/java/org/apache/cxf/systest/schemaimport/ServiceImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.schemaimport;

import javax.jws.WebService;
@WebService(targetNamespace = "http://cxf.apache.org/xsd/test/", name = "service_v1_port",
            wsdlLocation = "classpath:/wsdl_systest/service.wsdl",
            serviceName = "service_v1",
            endpointInterface = "org.apache.cxf.systest.schemaimport.ServiceV1Port")
public class ServiceImpl implements ServiceV1Port {

    @Override
    public ResponseType testRequest(RequestType request) {
        System.out.println(request.getRequest().getSomeMeasure());
        ResponseType responseType = new ResponseType();
        responseType.setText("Response from server");
        return responseType;
    }

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/systests/uncategorized/src/test/java/org/apache/cxf/systest/schemaimport/ServiceImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.schemaimport;

import jakarta.jws.WebService;
@WebService(targetNamespace = "http://cxf.apache.org/xsd/test/", name = "service_v1_port",
            wsdlLocation = "classpath:/wsdl_systest/service.wsdl",
            serviceName = "service_v1",
            endpointInterface = "org.apache.cxf.systest.schemaimport.ServiceV1Port")
public class ServiceImpl implements ServiceV1Port {

    @Override
    public ResponseType testRequest(RequestType request) {
        System.out.println(request.getRequest().getSomeMeasure());
        ResponseType responseType = new ResponseType();
        responseType.setText("Response from server");
        return responseType;
    }

}
